@@ -278,9 +278,19 @@ class CLI(object):
         input = method(prompt + ': '.encode('ascii'))
         return input
 
-    def confirm(self, prompt, default='n'):
+    def confirm(self, args, prompt, default='n'):
         choice = ' [Y/n]' if default == 'y' else ' [y/N]'
-        input = raw_input(prompt + choice + ': ').lower()
+        text = prompt + choice + ': '
+
+        if args.assume_yes:
+            print text, 'Y'
+            return True
+
+        if args.assume_no:
+            print text, 'N'
+            return False
+
+        input = raw_input(text).lower()
         if input == '':
             input = default
         return re.match(r'^y(?:es)?$', input.strip(), re.IGNORECASE)
@@ -347,9 +357,15 @@ class CLI(object):
 
     def cmd_setup(self, args):
         if args.api_key:
-            # API Key
-            self.info('You can find your API key at https://account.dotcloud.com/settings/')
-            api_key = self.prompt('Please enter your API key')
+            if 'DOTCLOUD_API_KEY' in os.environ:
+                self.info('Using API key configured at environment variable'
+                          ' DOTCLOUD_API_KEY.')
+                api_key = os.environ['DOTCLOUD_API_KEY']
+            else:
+                # API Key
+                self.info('You can find your API key at https://account.dotcloud.com/settings/')
+                api_key = self.prompt('Please enter your API key')
+
             if not re.match('\w{20}:\w{40}', api_key):
                 self.die('Invalid API Key')
             config = GlobalConfig()
@@ -433,7 +449,7 @@ class CLI(object):
             else:
                 self.die('Creating application "{0}" failed: {1}'.format(args.application, e))
         self.success('Application "{0}" created.'.format(args.application))
-        if self.confirm('Connect the current directory to "{0}"?'.format(args.application), 'y'):
+        if self.confirm(args, 'Connect the current directory to "{0}"?'.format(args.application), 'y'):
             self._connect(args)
 
     def cmd_traffic(self, args):
@@ -542,7 +558,7 @@ class CLI(object):
             to_destroy = '{0}.{1}'.format(args.application, args.service)
             url = '/applications/{0}/services/{1}'.format(args.application, args.service)
 
-        if not self.confirm('Destroy the {0} "{1}"?'.format(what_destroy, to_destroy)):
+        if not self.confirm(args, 'Destroy the {0} "{1}"?'.format(what_destroy, to_destroy)):
             return
         self.info('Destroying "{0}"'.format(to_destroy))
         try:
@@ -901,7 +917,7 @@ class CLI(object):
                     "Are you sure you entered the correct directory path?".format(
                         args.path
                 )
-                if not self.confirm(question):
+                if not self.confirm(args, question):
                     self.die()
         else :
             if root is None :
@@ -910,7 +926,7 @@ class CLI(object):
                         "Are you sure you are in the correct directory?".format(
                             os.getcwd()
                     )
-                    if not self.confirm(question):
+                    if not self.confirm(args, question):
                         self.die()
             else :
                 if not os.path.exists(os.path.join(self.local_config_root, 'dotcloud.yml')):
@@ -920,7 +936,7 @@ class CLI(object):
                         "Continue?".format(
                         self.local_config_root
                     )
-                    if not self.confirm(question):
+                    if not self.confirm(args, question):
                         self.die()
 
     @app_local
@@ -1051,7 +1067,9 @@ class CLI(object):
         excludes = ('*.pyc', '.git', '.hg')
         ignore_file = os.path.join(local_dir, '.dotcloudignore')
         ignore_opt = ('--exclude-from', ignore_file) if os.path.exists(ignore_file) else tuple()
-        rsync = ('rsync', '-lpthrvz', '--delete', '--safe-links', '--progress') + \
+        verbose_opt = ('--verbose', '--progress') if args.verbose else tuple()
+        rsync = ('rsync', '-lpthrz', '--delete', '--safe-links') + \
+                 verbose_opt + \
                  tuple('--exclude={0}'.format(e) for e in excludes) + \
                  ignore_opt + \
                  ('-e', ssh, local_dir,
@@ -1107,6 +1125,7 @@ class CLI(object):
         return [
             'ssh',
             '-i', self.global_config.key,
+            '-o', 'IdentitiesOnly=yes',
             '-o', 'StrictHostKeyChecking=no',
             '-o', 'PasswordAuthentication=no',
             '-o', 'ServerAliveInterval=10',
@@ -1553,7 +1572,7 @@ class CLI(object):
             self.success("All the services are up to date in {0}".format(args.application))
             return
 
-        if upgrade and not args.dry_run and self.confirm("Upgrade {0}?".format(", ".join(upgrade))):
+        if upgrade and not args.dry_run and self.confirm(args, "Upgrade {0}?".format(", ".join(upgrade))):
             manual_upgrades = upgradeable - upgrade
             if len(upgrade) == 1:
                 single_service = upgrade.pop()
